package com.playlet.system.service;

import java.util.List;

import com.playlet.system.domain.PlayletWithdrawApproval;
import com.baomidou.mybatisplus.extension.service.IService;


/**
 * @Date: 2024-03-30 08:35
 * @Author: 但星霖
 * @Version: v1.0
 * @Description: 提现审批Service接口
 */
public interface IPlayletWithdrawApprovalService extends IService<PlayletWithdrawApproval> {
    /**
     * 查询提现审批
     *
     * @param id 提现审批主键
     * @return 提现审批
     */
    PlayletWithdrawApproval selectPlayletWithdrawApprovalById(Long id);

    /**
     * 查询提现审批列表
     *
     * @param playletWithdrawApproval 提现审批
     * @return 提现审批集合
     */
    List<PlayletWithdrawApproval> selectPlayletWithdrawApprovalList(PlayletWithdrawApproval playletWithdrawApproval);

    /**
     * 新增提现审批
     *
     * @param playletWithdrawApproval 提现审批
     * @return 结果
     */
    int insertPlayletWithdrawApproval(PlayletWithdrawApproval playletWithdrawApproval);

    /**
     * 修改提现审批
     *
     * @param playletWithdrawApproval 提现审批
     * @return 结果
     */
    int updatePlayletWithdrawApproval(PlayletWithdrawApproval playletWithdrawApproval);

    /**
     * 批量删除提现审批
     *
     * @param ids 需要删除的提现审批主键集合
     * @return 结果
     */
    int deletePlayletWithdrawApprovalByIds(String ids);

    /**
     * 删除提现审批信息
     *
     * @param id 提现审批主键
     * @return 结果
     */
    int deletePlayletWithdrawApprovalById(Long id);
}
